@@ -16,6 +16,7 @@ OC.L10N.register(
     "Save" : "Сохранить",
     "Allowed characters {count} of {max}" : "Допустимых символов {count} из {max}",
     "{count} unread comments" : "{count} непрочитанных комментариев",
-    "Comment" : "Коментарий"
+    "Comment" : "Коментарий",
+    "<strong>Comments</strong> for files" : "<strong>Комментарии</strong> к файлам"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
