@@ -81,6 +81,7 @@ OC.L10N.register(
     "Advanced settings" : "Haladó beállítások",
     "Delete" : "Törlés",
     "Allow users to mount external storage" : "Külső tárolók engedélyezése a felhasználók részére",
-    "Allow users to mount the following external storage" : "A felhasználók számára engedélyezett külső tárolók:"
+    "Allow users to mount the following external storage" : "A felhasználók számára engedélyezett külső tárolók:",
+    "SMB / CIFS" : "SMB / CIFS"
 },
 "nplurals=2; plural=(n != 1);");
