@@ -6,9 +6,10 @@ OC.L10N.register(
     "Grant access" : "Permite accesul",
     "Access granted" : "Acces permis",
     "Saved" : "Salvat",
-    "None" : "Niciuna",
     "Username" : "Nume utilizator",
     "Password" : "Parolă",
+    "Save" : "Salvează",
+    "None" : "Niciuna",
     "API key" : "Cheie API",
     "Public key" : "Cheie publică",
     "Amazon S3" : "Amazon S3",
@@ -29,9 +30,8 @@ OC.L10N.register(
     "External Storage" : "Stocare externă",
     "Folder name" : "Denumire director",
     "Configuration" : "Configurație",
-    "Delete" : "Șterge",
     "Add storage" : "Adauga stocare",
-    "Enable User External Storage" : "Permite stocare externă pentru utilizatori",
+    "Delete" : "Șterge",
     "Allow users to mount the following external storage" : "Permite utilizatorilor să monteze următoarea unitate de stocare"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
