@@ -65,6 +65,10 @@ class Share20OCSTest extends \Test\TestCase {
 		$this->shareManager = $this->getMockBuilder('OCP\Share\IManager')
 			->disableOriginalConstructor()
 			->getMock();
+		$this->shareManager
+			->expects($this->any())
+			->method('shareApiEnabled')
+			->willReturn(true);
 		$this->groupManager = $this->getMock('OCP\IGroupManager');
 		$this->userManager = $this->getMock('OCP\IUserManager');
 		$this->request = $this->getMock('OCP\IRequest');
@@ -203,12 +207,14 @@ class Share20OCSTest extends \Test\TestCase {
 		$file->method('getPath')->willReturn('file');
 		$file->method('getStorage')->willReturn($storage);
 		$file->method('getParent')->willReturn($parentFolder);
+		$file->method('getMimeType')->willReturn('myMimeType');
 
 		$folder = $this->getMock('OCP\Files\Folder');
 		$folder->method('getId')->willReturn(2);
 		$folder->method('getPath')->willReturn('folder');
 		$folder->method('getStorage')->willReturn($storage);
 		$folder->method('getParent')->willReturn($parentFolder);
+		$folder->method('getMimeType')->willReturn('myFolderMimeType');
 
 		// File shared with user
 		$share = $this->createShare(
@@ -247,7 +253,8 @@ class Share20OCSTest extends \Test\TestCase {
 			'storage' => 101,
 			'mail_send' => 0,
 			'uid_file_owner' => 'ownerId',
-			'displayname_file_owner' => 'ownerDisplay'
+			'displayname_file_owner' => 'ownerDisplay',
+			'mimetype' => 'myMimeType',
 		];
 		$data[] = [$share, $expected];
 
@@ -288,7 +295,8 @@ class Share20OCSTest extends \Test\TestCase {
 			'storage' => 101,
 			'mail_send' => 0,
 			'uid_file_owner' => 'ownerId',
-			'displayname_file_owner' => 'ownerDisplay'
+			'displayname_file_owner' => 'ownerDisplay',
+			'mimetype' => 'myFolderMimeType',
 		];
 		$data[] = [$share, $expected];
 
@@ -333,7 +341,8 @@ class Share20OCSTest extends \Test\TestCase {
 			'mail_send' => 0,
 			'url' => 'url',
 			'uid_file_owner' => 'ownerId',
-			'displayname_file_owner' => 'ownerDisplay'
+			'displayname_file_owner' => 'ownerDisplay',
+			'mimetype' => 'myFolderMimeType',
 		];
 		$data[] = [$share, $expected];
 
@@ -754,9 +763,12 @@ class Share20OCSTest extends \Test\TestCase {
 				->with('valid-path')
 				->willReturn($path);
 
-		$group = $this->getMock('\OCP\IGroup');
 		$this->groupManager->method('groupExists')->with('validGroup')->willReturn(true);
 
+		$this->shareManager->expects($this->once())
+			->method('allowGroupSharing')
+			->willReturn(true);
+
 		$share->method('setPath')->with($path);
 		$share->method('setPermissions')->with(\OCP\Constants::PERMISSION_ALL);
 		$share->method('setShareType')->with(\OCP\Share::SHARE_TYPE_GROUP);
@@ -770,6 +782,51 @@ class Share20OCSTest extends \Test\TestCase {
 		$this->assertEquals($expected->getData(), $result->getData());
 	}
 
+	public function testCreateShareGroupNotAllowed() {
+		$share = $this->getMock('\OCP\Share\IShare');
+		$this->shareManager->method('newShare')->willReturn($share);
+
+		$this->request
+			->method('getParam')
+			->will($this->returnValueMap([
+				['path', null, 'valid-path'],
+				['permissions', null, \OCP\Constants::PERMISSION_ALL],
+				['shareType', '-1', \OCP\Share::SHARE_TYPE_GROUP],
+				['shareWith', null, 'validGroup'],
+			]));
+
+		$userFolder = $this->getMock('\OCP\Files\Folder');
+		$this->rootFolder->expects($this->once())
+			->method('getUserFolder')
+			->with('currentUser')
+			->willReturn($userFolder);
+
+		$path = $this->getMock('\OCP\Files\Folder');
+		$storage = $this->getMock('OCP\Files\Storage');
+		$storage->method('instanceOfStorage')
+			->with('OCA\Files_Sharing\External\Storage')
+			->willReturn(false);
+		$path->method('getStorage')->willReturn($storage);
+		$userFolder->expects($this->once())
+			->method('get')
+			->with('valid-path')
+			->willReturn($path);
+
+		$this->groupManager->method('groupExists')->with('validGroup')->willReturn(true);
+
+		$this->shareManager->expects($this->once())
+			->method('allowGroupSharing')
+			->willReturn(false);
+
+		$share->method('setPath')->with($path);
+
+		$expected = new \OC_OCS_Result(null, 404, 'group sharing is disabled by the administrator');
+		$result = $this->ocs->createShare();
+
+		$this->assertEquals($expected->getMeta(), $result->getMeta());
+		$this->assertEquals($expected->getData(), $result->getData());
+	}
+
 	public function testCreateShareLinkNoLinksAllowed() {
 		$this->request
 			->method('getParam')
@@ -1514,6 +1571,9 @@ class Share20OCSTest extends \Test\TestCase {
 		$folder = $this->getMock('\OCP\Files\Folder');
 		$parent = $this->getMock('\OCP\Files\Folder');
 
+		$file->method('getMimeType')->willReturn('myMimeType');
+		$folder->method('getMimeType')->willReturn('myFolderMimeType');
+
 		$file->method('getPath')->willReturn('file');
 		$folder->method('getPath')->willReturn('folder');
 
@@ -1578,6 +1638,7 @@ class Share20OCSTest extends \Test\TestCase {
 				'share_with' => 'recipient',
 				'share_with_displayname' => 'recipient',
 				'mail_send' => 0,
+				'mimetype' => 'myMimeType',
 			], $share, [], false
 		];
 
@@ -1606,6 +1667,7 @@ class Share20OCSTest extends \Test\TestCase {
 				'share_with' => 'recipient',
 				'share_with_displayname' => 'recipientDN',
 				'mail_send' => 0,
+				'mimetype' => 'myMimeType',
 			], $share, [
 				['owner', $owner],
 				['initiator', $initiator],
@@ -1649,6 +1711,7 @@ class Share20OCSTest extends \Test\TestCase {
 				'share_with' => 'recipient',
 				'share_with_displayname' => 'recipient',
 				'mail_send' => 0,
+				'mimetype' => 'myMimeType',
 			], $share, [], false
 		];
 
@@ -1687,6 +1750,7 @@ class Share20OCSTest extends \Test\TestCase {
 				'share_with' => 'recipient',
 				'share_with_displayname' => 'recipient',
 				'mail_send' => 0,
+				'mimetype' => 'myMimeType',
 			], $share, [], false
 		];
 
@@ -1727,7 +1791,8 @@ class Share20OCSTest extends \Test\TestCase {
 				'share_with' => 'mypassword',
 				'share_with_displayname' => 'mypassword',
 				'mail_send' => 0,
-				'url' => 'myLink'
+				'url' => 'myLink',
+				'mimetype' => 'myMimeType',
 			], $share, [], false
 		];
 
@@ -1766,6 +1831,7 @@ class Share20OCSTest extends \Test\TestCase {
 				'share_with' => 'user@server.com',
 				'share_with_displayname' => 'user@server.com',
 				'mail_send' => 0,
+				'mimetype' => 'myFolderMimeType',
 			], $share, [], false
 		];
 
@@ -1813,7 +1879,74 @@ class Share20OCSTest extends \Test\TestCase {
 		} catch (NotFoundException $e) {
 			$this->assertTrue($exception);
 		}
+	}
+
+	/**
+	 * @return Share20OCS
+	 */
+	public function getOcsDisabledAPI() {
+		$shareManager = $this->getMockBuilder('OCP\Share\IManager')
+			->disableOriginalConstructor()
+			->getMock();
+		$shareManager
+			->expects($this->any())
+			->method('shareApiEnabled')
+			->willReturn(false);
+
+		return new Share20OCS(
+			$shareManager,
+			$this->groupManager,
+			$this->userManager,
+			$this->request,
+			$this->rootFolder,
+			$this->urlGenerator,
+			$this->currentUser
+		);
+	}
+
+	public function testGetShareApiDisabled() {
+		$ocs = $this->getOcsDisabledAPI();
+
+		$expected = new \OC_OCS_Result(null, 404, 'Share API is disabled');
+		$result = $ocs->getShare('my:id');
+
+		$this->assertEquals($expected, $result);
+	}
+
+	public function testDeleteShareApiDisabled() {
+		$ocs = $this->getOcsDisabledAPI();
+
+		$expected = new \OC_OCS_Result(null, 404, 'Share API is disabled');
+		$result = $ocs->deleteShare('my:id');
+
+		$this->assertEquals($expected, $result);
+	}
 
 
+	public function testCreateShareApiDisabled() {
+		$ocs = $this->getOcsDisabledAPI();
+
+		$expected = new \OC_OCS_Result(null, 404, 'Share API is disabled');
+		$result = $ocs->createShare();
+
+		$this->assertEquals($expected, $result);
+	}
+
+	public function testGetSharesApiDisabled() {
+		$ocs = $this->getOcsDisabledAPI();
+
+		$expected = new \OC_OCS_Result();
+		$result = $ocs->getShares();
+
+		$this->assertEquals($expected, $result);
+	}
+
+	public function testUpdateShareApiDisabled() {
+		$ocs = $this->getOcsDisabledAPI();
+
+		$expected = new \OC_OCS_Result(null, 404, 'Share API is disabled');
+		$result = $ocs->updateShare('my:id');
+
+		$this->assertEquals($expected, $result);
 	}
 }
