@@ -2,7 +2,7 @@ OC.L10N.register(
     "ownpad_lite",
     {
     "Document was shared" : "문서 공유됨",
-    "User %s shared quick document %s with you." : "%s 님이 빠른 문서 %s을(를) 공유하였습니다.",
+    "User %s shared quick document %s with you." : "%s 님이 빠른 문서 %s을(를) 공유했습니다.",
     "My pad" : "내 패드",
     "Settings" : "설정",
     "Pad Title" : "패드 제목",
