@@ -6,6 +6,7 @@ OC.L10N.register(
     "No entries found in this folder" : "Нема ничега у овој фасцикли",
     "Name" : "назив",
     "Size" : "величина",
-    "Modified" : "Измењен"
+    "Modified" : "Измењен",
+    "Tagged files" : "Означени фајлови"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
