@@ -1025,14 +1025,6 @@ class Access extends LDAPUtility implements user\IUserTools {
 				return array();
 			}
 
-			// Do the server-side sorting
-			foreach(array_reverse($attr) as $sortAttr){
-				foreach($sr as $searchResource) {
-					$this->ldap->sort($cr, $searchResource, $sortAttr);
-				}
-			}
-
-
 			foreach($sr as $res) {
 				$findings = array_merge($findings, $this->ldap->getEntries($cr	, $res ));
 			}
